@@ -1,9 +1,8 @@
-#!/usr/local/bin/perl
 # Before `make install' is performed this script should be runnable 
 # with # `make test'. 
 # After `make install' it should work as `perl test.pl'
 
 use Test::Harness;
 # Test::Harness::verbose=1;
-runtests(qw(t/ab_Header.t));
+runtests(qw(t/AppBuilder::Header.t));
 
